==> agschat-0.0.5.tar.gz: example/lib/view/widgets/video_player.dart <==
import 'package:agschat_example/helper/colors.dart';
import 'package:agschat_example/helper/custom_styles.dart';
import 'package:better_player/better_player.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

class VideoPlayerView extends StatefulWidget {
  const VideoPlayerView({
    Key? key,
  }) : super(key: key);

  @override
  _VideoPlayerViewState createState() => _VideoPlayerViewState();
}

class _VideoPlayerViewState extends State<VideoPlayerView> {
  BetterPlayerController? _betterPlayerController;
  BetterPlayerDataSource? _dataSource;
  var mediaUrl = "".obs;

  @override
  void initState() {
    super.initState();
    if (Get.arguments != null) {
      mediaUrl.value = Get.arguments[0];
      var isUrl = Get.arguments[1];
      playVideo(mediaUrl.value, isUrl);
    }
  }

  playVideo(url, isUrl) {
    if (isUrl) {
      _dataSource =
          BetterPlayerDataSource(BetterPlayerDataSourceType.network, url);
    } else {
      _dataSource =
          BetterPlayerDataSource(BetterPlayerDataSourceType.file, url);
    }

    _betterPlayerController = BetterPlayerController(
      BetterPlayerConfiguration(
        expandToFill: false,
        autoPlay: true,
        autoDispose: false,
        fullScreenByDefault: false,
        fit: BoxFit.fill,
        autoDetectFullscreenDeviceOrientation: true,
        errorBuilder: (context, err) {
          return Text(err!);
        },
        controlsConfiguration: const BetterPlayerControlsConfiguration(
          controlBarColor: Colors.transparent,
          iconsColor: Colors.white,
          playIcon: Icons.play_circle_fill_rounded,
          pauseIcon: Icons.pause_circle_filled_outlined,
          progressBarPlayedColor: Colors.grey,
          progressBarHandleColor: Colors.grey,
          enableSkips: true,
          enableFullscreen: true,
          controlBarHeight: 60,
          loadingColor: Colors.white,
          overflowModalColor: Colors.transparent,
          overflowModalTextColor: Colors.white,
          overflowMenuIconsColor: Colors.white,
        ),
      ),
      betterPlayerDataSource: _dataSource,
    );
  }

  @override
  void dispose() {
    super.dispose();
    if (mediaUrl.isNotEmpty) {
      _betterPlayerController!.videoPlayerController!.pause();
      _betterPlayerController!.videoPlayerController!.dispose();
      _betterPlayerController!.dispose();
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.black,
      appBar: AppBar(
        backgroundColor: themeColor,
        elevation: 0.8,
        title: Text(
          "Video",
          style: CustomTextStyles.medium(
            fontSize: 16.0,
            fontColor: Colors.black,
          ),
        ),
        iconTheme: const IconThemeData(color: Colors.black),
      ),
      body: Center(
        child: BetterPlayer(
          controller: _betterPlayerController!,
        ),
      ),
    );
  }
}

==> agschat-0.0.15.tar.gz: example/lib/view/widgets/video_player.dart <==
import 'package:agschat_example/helper/colors.dart';
import 'package:agschat_example/helper/custom_styles.dart';
import 'package:better_player/better_player.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

class VideoPlayerView extends StatefulWidget {
  VideoPlayerView({
    Key? key,
    this.videoFile,
    this.isVideoUrl,
  }) : super(key: key);
  var videoFile;
  var isVideoUrl;
  @override
  _VideoPlayerViewState createState() => _VideoPlayerViewState();
}

class _VideoPlayerViewState extends State<VideoPlayerView> {
  BetterPlayerController? _betterPlayerController;
  BetterPlayerDataSource? _dataSource;
  var mediaUrl = "".obs;

  @override
  void initState() {
    super.initState();
    mediaUrl.value = widget.videoFile;
    var isUrl = widget.isVideoUrl;
    playVideo(mediaUrl.value, isUrl);
  }

  playVideo(url, isUrl) {
    if (isUrl) {
      _dataSource =
          BetterPlayerDataSource(BetterPlayerDataSourceType.network, url);
    } else {
      _dataSource =
          BetterPlayerDataSource(BetterPlayerDataSourceType.file, url);
    }

    _betterPlayerController = BetterPlayerController(
      BetterPlayerConfiguration(
        expandToFill: false,
        autoPlay: true,
        autoDispose: false,
        fullScreenByDefault: false,
        fit: BoxFit.fill,
        autoDetectFullscreenDeviceOrientation: true,
        errorBuilder: (context, err) {
          return Text(err!);
        },
        controlsConfiguration: const BetterPlayerControlsConfiguration(
          controlBarColor: Colors.transparent,
          iconsColor: Colors.white,
          playIcon: Icons.play_circle_fill_rounded,
          pauseIcon: Icons.pause_circle_filled_outlined,
          progressBarPlayedColor: Colors.grey,
          progressBarHandleColor: Colors.grey,
          enableSkips: true,
          enableFullscreen: true,
          controlBarHeight: 60,
          loadingColor: Colors.white,
          overflowModalColor: Colors.transparent,
          overflowModalTextColor: Colors.white,
          overflowMenuIconsColor: Colors.white,
        ),
      ),
      betterPlayerDataSource: _dataSource,
    );
  }

  @override
  void dispose() {
    super.dispose();
    if (mediaUrl.isNotEmpty) {
      _betterPlayerController!.videoPlayerController!.pause();
      _betterPlayerController!.videoPlayerController!.dispose();
      _betterPlayerController!.dispose();
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.black,
      appBar: AppBar(
        backgroundColor: themeColor,
        elevation: 0.8,
        title: Text(
          "Video",
          style: CustomTextStyles.medium(
            fontSize: 16.0,
            fontColor: Colors.black,
          ),
        ),
        iconTheme: const IconThemeData(color: Colors.black),
      ),
      body: Center(
        child: BetterPlayer(
          controller: _betterPlayerController!,
        ),
      ),
    );
  }
}
